﻿Ext.require('App.Const.Finances');
Ext.define('App.View.Kivii.Finances.Statistic.Settlement.Group', {
    extend: 'System.Control.EntityList',
    xtype: 'App.View.Kivii.Finances.Statistic.Settlement.Group',
    entityType: 'Kivii.Finances.Entities.Settlement',
    requires: ['System.Control.ComboSelector', 'System.Control.CategoryField','App.Control.DownloadField'],
    dataSource: '/Restful/Kivii.Finances.Entities.Settlement/StatisticGroup.json',
    globalFilter: {},
    filter: {
        BeginTime: new Date(new Date().getFullYear(), new Date().getMonth() - 1, 1),
        EndTime: new Date(new Date().getFullYear(), new Date().getMonth(), 1),
        // Type:'Report',
        GroupType: 'Depart'
    },
    //在末尾保留足够的滚动条大小的控件
    reserveScrollbar: true,
    //默认情况下启用缓冲渲染
    //启用缓存会造成空白行的问题,有些数据过多会预留渲染控件,切换成数据少的会预留空白
    bufferedRenderer: false,
    header: true,
    layout: 'fit',
    title: '部门结算统计',
    iconCls: 'x-fa fa-trello',
    viewModel: {
        data: {
            // AmountTask: 0,
            // AmountTaskTotal: 0,
            // AmountTaskDiscount: 0,
            // AmountTaskDiscountTotal: 0,
            // AmountPackage: 0,
            // AmountCalculation: 0,
            // AmountReport: 0,
            // AmountReportChange: 0,
            // AmountPayment: 0,
            // DiscountRate: 0,
            // reportQuantity: 0,
            // xReportQuantity: 0,
            _selection: null,
            lastOwnerKvid: null
        }
    },
    bind: {
        selection: '{_selection}'
    },
    store: {
        autoLoad: true,
        pageSize: 800,
        sorters: [{
            property: 'CreateTime',
            direction: 'ASC'
        }]
    },
    dockedItems: [{
        xtype: 'toolbar',
        dock: 'top',
        overflowHandler: 'scroller',
        items: [{
            xtype: 'categoryField',
            fieldLabel: '类型',
            labelWidth: 30,
            width: 160,
            entityType: 'Kivii.Finances.Entities.Settlement',
            internalCode: 'Type',
            // value:'报告',
            listeners:{
            	select: '_onSelectType'
            }
        }, {
            xtype: 'categoryField',
            fieldLabel: '分类',
            readOnly: true,
            reference: 'category',
            labelWidth: 30,
            width: 160,
            entityType: 'Kivii.Finances.Entities.Settlement',
            internalCode: 'Category',
            // value:'报告',
            listeners:{
            	select: '_onSelectCategory'
            }
        },{
            xtype: 'datefield',
            fieldLabel: '业务时间  开始',
            format: 'Y-m-d',
            labelWidth: 90,
            width: 220,
            reference: 'startTime',
            editable: false,
            value: new Date(new Date().getFullYear(), new Date().getMonth() - 1, 1),
            // value: new Date(),
            listeners: {
                select: '_onSelectMonth'
            }
        }, {
            xtype: 'datefield',
            fieldLabel: '结束',
            format: 'Y-m-d',
            labelWidth: 30,
            width: 160,
            reference: 'endTime',
            editable: false,
            value: new Date(new Date().getFullYear(), new Date().getMonth(), 0),
            // value: new Date(),
            listeners: {
                select: '_onSelectMonth'
            }
        }, {
            xtype: 'searchField',
            flex: 1,
            labelWidth: 60,
            queryField: 'PayerName,BizId',
            emptyText: '模糊搜索付款单位、所属报告'
        }, {
            xtype: 'downloadField',
            dataSource: '/Restful/Kivii.Finances.Entities.Settlement/StatisticGroup.xlsx', //数据源
            fileName: '数据导出',
            window: {
                type: 'App.Control.Kivii.Finances.General.Template.Selector',
                title: '选择模板',
                iconCls: 'x-fa fa-file-excel-o',
                autoScroll: true,
                width: 700,
                height: 350,
                closeAction: 'hide',
                modal: true,
                layout: 'fit',
                filter: {
                    FolderPath: '/Finances/Settlement/Files',
                    TagsContains: 'StatisticGroup'
                }
            }
        }]
    },{
        xtype: 'pagingtoolbar',
        dock: 'bottom',
        displayInfo: true,
        items: [{
            xtype: 'button',
            labelWidth: 60,
            iconCls: 'x-fa fa-check-square-o',
            bind: {
                text: '已选择{selectionCount}条记录,点击清除',
                hidden: '{selectionCount==0}'
            },
            handler: '_onClearSelections'
        }]
    }],
    columns: {
        defaults: {
            menuDisabled: true,
            sortable: false
        },
        items: [{
            xtype: 'rownumberer'
        }, {
            dataIndex: 'Summary',
            text: '部门',
            minWidth: 200,
            flex:1
        }, {
            dataIndex: 'Quantity',
            text: '结算数量',
            width: 100
        }, {
            dataIndex: 'Amount',
            align: 'right',
            text: '结算金额',
            width: 150
        }, {
            dataIndex: 'QuantityPayment',
            text: '收款数量',
            width: 100
        }, {
            dataIndex: 'AmountPayment',
            align: 'right',
            text: '已收款金额',
            width: 150
        }, {
            dataIndex: 'QuantityUnpaid',
            text: '未收数量',
            width: 100
        }, {
            dataIndex: 'AmountUnpaid',
            align: 'right',
            text: '未收款金额',
            width: 150
            // summaryType: 'sum',
            // summaryRenderer: function(value, summaryData, dataIndex) {
            //     return Ext.String.format('￥{0}', value.toFixed(2));
            // }
        }]
    },
    listeners: {
        activate: '_onActivate',
        // viewready: '_viewReady'
    },
    controller: {
        _onActivate: function(_ctrl, _eOpts) {
            this.getView().reload();
        },
        _onClearSelections: function() {
            this.getView().clearSelections();
        },
        _renderAmount: function(_value, _meta, _record, _rowIndex) {
            return _record.data.Amount-_record.data.AmountPayment;
        },
        _viewReady: function() {
            var _me = this;
            var _view = _me.getView();
            var _vm = _me.getViewModel();
            var _store = _view.getStore();
            _store.on('load', function(_this, _records, _successful, _operation, _eOpts) {
            	// for (let _i = 0; _i < _records.length; _i++) {
            	// 	_records[_i].data.AmountUnpaid=_records[_i].data.Amount-_records[_i].data.AmountPayment;
            	// }
                // let _rtns = Ext.decode(_operation.getResponse().responseText);
                // _vm.set('AmountSettlement', _rtns.TotalAmount.toFixed(2));
                // _vm.set('AmountPayment', _rtns.TotalAmountPayment.toFixed(2));
                // _vm.set('AmountUnpaid', _rtns.TotalAmountUnpaid.toFixed(2));
                // _vm.set('AmountOffset', _rtns.TotalAmountOffset.toFixed(2));
                // _vm.set('Quantity', _rtns.TotalQuantity.toFixed(0));
                // _vm.set('QuantityPayment', _rtns.TotalQuantityPayment.toFixed(0));
                // _vm.set('QuantityUnpaid', _rtns.TotalQuantityUnpaid.toFixed(0));
                // _vm.set('QuantitySettlement', _rtns.TotalQuantity.toFixed(0));
                // _vm.set('QuantityOffset', _rtns.TotalQuantityOffset.toFixed(0));
            });
        },
        _onSelectMonth: function(_ctrl, _time, _eOpts) {
            var _controller = this;
            var _view = _controller.getView();
            var _refs = _controller.getReferences();
            var _startTime = _refs.startTime.value;
            var _endTime = _refs.endTime.value || new Date();
            if (_startTime === null) {
                Ext.toast("请选择开始时间!");
                return;
            }
            if (_startTime > _endTime) {
                Ext.toast("开始日期不能大于结束日期!");
                return;
            }
            delete _view.filter.BeginTime;
            delete _view.filter.EndTime;
            _view.filter.BeginTime = new Date(_startTime.getFullYear(), _startTime.getMonth(), _startTime.getDate());
            _view.filter.EndTime = new Date(_endTime.getFullYear(), _endTime.getMonth(), _endTime.getDate() + 1);
            _view.reload();
        },
        _onSelectType: function(_ctrl, _record) {
            let _controller = this;
            let _view = _controller.getView();
            let _refs = _controller.getReferences();
            delete _view.filter.Type;
            _view.filter.Type = _record.data.InternalCode;
            let _category = _refs.category;
            if (_record.data.InternalCode==="Service") {
                _category.setReadOnly(false);
            } else {
                _category.setReadOnly(true);
                _category.setValue(null);
                delete _view.filter.Category;
            }
            _view.reload();
        },
        _onSelectCategory: function(_ctrl, _record, _eOpts) {
            let _controller = this;
            let _view = _controller.getView();
            let _refs = _controller.getReferences();
            delete _view.filter.Category;
            _view.filter.Category = _record.data.InternalCode;
            _view.reload();
        }
    }
});