﻿Ext.require('App.Const.Finances');
Ext.define('App.View.Kivii.Finances.InvoiceApply.Payment.List', {
    extend: 'System.Control.EntitySelector',
    entityType: 'Kivii.Finances.Entities.Payment',
    xtype: 'App.View.Kivii.Finances.InvoiceApply.Payment.List',
    dataSource: '/Restful/Kivii.Finances.Entities.Payment/InvoiceApplyQuery.json',
    title: '申请开票',
    iconCls: 'x-fa fa-money',
    filter: {
        OwnerKvid: KiviiContext.CurrentMember.DepartmentKvid
    },
    //在末尾保留足够的滚动条大小的控件
    reserveScrollbar: true,
    //默认情况下启用缓冲渲染
    //启用缓存会造成空白行的问题,有些数据过多会预留渲染控件,切换成数据少的会预留空白
    bufferedRenderer: false,
    viewModel: {
        data: {
            _selection: null
        }
    },
    store: {
        autoLoad: true,
        pageSize: 100,
        sorters: [{
            property: 'OperateTime',
            direction: 'DESC'
        }]
    },
    features: [{
        ftype: 'summary'
    }],
    selModel: {
        selType: 'checkboxmodel',
        checkboxSelect: true,
        pruneRemoved: false,
        extensible: 'y'
    },
    bind: {
        selection: '{_selection}'
    },
    dockedItems: [{
        xtype: 'pagingtoolbar',
        dock: 'bottom',
        displayInfo: true,
        items: [{
            xtype: 'button',
            labelWidth: 60,
            iconCls: 'x-fa fa-check-square-o',
            bind: {
                text: '已选择{selectionCount}条记录,点击清除',
                hidden: '{selectionCount==0}'
            },
            handler: '_onClearSelections'
        }]
    }, {
        xtype: 'toolbar',
        dock: 'top',
        overflowHandler: 'scroller',
        items: [{
            margin: '0 3 -10 3',
            xtype: 'displayfield',
            value: '<div style="color:red">若未找到开票收款,请先到账管理中认领</div>',
            fieldStyle: {
                fontSize: '20px'
            }
        }, {
            xtype: 'searchField',
            flex: 1,
            minWidth: 250,
            labelWidth: 60,
            queryField: 'SerialNumber,PayerName,PayerAccountName,PayerAccountSerialNumber',
            emptyText: '模糊搜索流水号、付款单位、收付款账号或名称'
        }, {
            text: '申请开票',
            iconCls: 'x-fa fa-money',
            type: 'Payment',
            handler: '_onCreateApply',
            bind: {
                disabled: '{!_selection}'
            }
        }, {
        	xtype: 'splitbutton',
            text: '录入发票',
            multiple:false,
            iconCls: 'x-fa fa-plus',
            iconAlign: 'left',
            handler: '_onAcceptInvoice',
            menu: [{
                text: '多发票',
                iconCls: 'x-fa fa-ticket',
                handler: '_onAcceptInvoice',
                multiple:true,
                bind: {
                    disabled: '{!_selection}'
                }
            }],
            bind: {
                disabled: '{!_selection}'
            }
        }]
    }],
    columns: {
        defaults: {
            menuDisabled: true,
            sortable: true
        },
        items: [{
            xtype: 'rownumberer',
            align: 'center',
            resizable: false
        }, {
            text: '流水号',
            dataIndex: 'SerialNumber',
            width: 120
        }, {
            text: '付款单位',
            dataIndex: 'PayerName',
            width: 220,
            summaryType: 'sum',
            summaryRenderer: function(value, summaryData, dataIndex) {
                return '合计 ￥';
            }
        }, {
            text: '认领金额',
            align: 'right',
            dataIndex: 'Amount',
            renderer: KiviiContext.Const.FinancesFunctionsMoneyToFmoney,
            summaryType: 'sum',
            summaryRenderer: function(value, summaryData, dataIndex) {
                return Ext.String.format('{0}', value.toFixed(2));
            },
            width: 110
        }, {
            text: '开票金额',
            align: 'right',
            dataIndex: 'AmountInvoice',
            renderer: KiviiContext.Const.FinancesFunctionsMoneyToFmoney,
            summaryType: 'sum',
            summaryRenderer: function(value, summaryData, dataIndex) {
                return Ext.String.format('{0}', value.toFixed(2));
            },
            width: 100
        }, {
            text: '付款类型',
            dataIndex: 'Type',
            renderer: '_renderType',
            width: 100
        }, {
            xtype: 'datecolumn',
            text: '认领日期',
            format: 'Y-m-d H:i',
            dataIndex: 'CreateTime',
            width: 150
        }, {
            xtype: 'datecolumn',
            text: '到账日期',
            format: 'Y-m-d H:i',
            dataIndex: 'OperateTime',
            width: 150
        }, {
            text: '摘要',
            dataIndex: 'Summary',
            width: 150
        }, {
            text: '备注',
            dataIndex: 'Remark',
            minWidth: 150,
            flex: 1
        }]
    },
    listeners: {
        activate: '_onActivate'
    },
    controller: {
        _onClearSelections: function() {
            this.getView().clearSelections();
        },
        _onActivate: function(_ctrl, _eOpts) {
            this.getView().reload();
        },
        _renderType: function(_value, _meta, _record, _rowIndex) {
            if (_value === 'Cash') {
                return '现金';
            }
            if (_value === 'Pos') {
                return '刷卡';
            }
            if (_value === 'AliPay') {
                return '支付宝';
            }
            if (_value === 'WeChat') {
                return '微信';
            }
            if (_value === 'Bank') {
                return '银行转账';
            }
            if (_value === 'Split') {
                return '已认领到账';
            }
            return _value;
        },
        _initEntity: function(_selecteds) {
            let _item = {};
            _item.Kvid=null;
            _item.OwnerKvid = KiviiContext.CurrentMember.DepartmentKvid;
            _item.OwnerName = KiviiContext.CurrentMember.DepartmentName;
            _item.OperateTime = new Date();
            _item.Type = "增值税专用发票";
            _item.TaxRate = 0.03;
            _item.Currency = "CNY";
            _item.PayerName = null;
            // _item.PayeeName = KiviiContext.CurrentMember.OrganizationName;
            _item.PayeeTaxNumber = null;
            _item.Amount = 0;
            _item.Metadata = {};
            // _item.Metadata.PayeeOperatorName=KiviiContext.CurrentMember.FullName;
            // _item.Metadata.ReviewerName=KiviiContext.CurrentMember.FullName;
            _item.OperatorName = KiviiContext.CurrentMember.FullName;
            _item.Details = [];
            _item.Payments = [];
            _item.PaymentKvids = [];
            for (let _i = 0; _i < _selecteds.length; _i++) {
                let _select = _selecteds[_i].data;
                let _payment = {};
                _payment.Kvid = _select.Kvid;
                _payment.Amount = parseFloat(parseFloat(_select.Amount - _select.AmountInvoice).toFixed(2));
                _item.Payments.push(_payment);
                _item.PaymentKvids.push(_select.Kvid);
                _item.Amount += _payment.Amount;
                _item.PayerName = _select.PayerName;
                _item.PayeeName = _select.PayeeName;
            }
            let _detail = {};
            _detail.GoodsId = "发票1";
            _detail.GoodsFullName = "检测费";
            _detail.GoodsModel = "3040601000000000000";
            _detail.TaxRate = _item.TaxRate;
            _detail.Quantity = 1;
            _detail.Amount = parseFloat(_item.Amount.toFixed(2));
            _detail.QuantityUnit = '次';
            _detail.AmountUntaxed = (parseFloat(_detail.Amount) / (1 + parseFloat(_detail.TaxRate))).toFixed(2);
            _detail.AmountTax = (parseFloat(_detail.Amount) - parseFloat(_detail.AmountUntaxed)).toFixed(2);
            _detail.QuantityUnitPrice = (parseFloat(_detail.Amount) / parseFloat(_detail.Quantity)).toFixed(2);
            _detail.QuantityUnitPriceUntaxed = (parseFloat(_detail.AmountUntaxed) / parseFloat(_detail.Quantity)).toFixed(2);
            _item.Details.push(_detail);
            return _item;
        },
        _onCreateApply: function(_ctrl) {
            let _controller = this;
            let _view = _controller.getView();
            let _vm = _controller.getViewModel();
            let _selecteds = _vm.data.selections || [];
            if (!_view.selection) return;
            if (_selecteds.length <= 0) return;
            for (let _i = 0; _i < _selecteds.length; _i++) {
                let _select = _selecteds[_i].data;
                let _msg = Ext.create('Ext.window.MessageBox', {
                    iconCls: _ctrl.iconCls,
                    iconAlign: 'left',
                    closeAction: 'destroy'
                });
                if (_select.PayerName !== _selecteds[0].data.PayerName) {
                    _msg.confirm(_ctrl.text, '所选到账中存在不同的付款单位,是否继续?', _controller._createApply, _controller);
                    return;
                }
            }
            _controller._createApply('yes');
        },
        _createApply: function(_optional) {
            if (_optional != "yes") return;
            let _controller = this;
            let _vm = _controller.getViewModel();
            let _view = _controller.getView();
            let _selecteds = _vm.data.selections || [];
            if (!_view.selection) return;
            if (_selecteds.length <= 0) return;
            let _apply = _controller._initEntity(_selecteds);
            _apply.OperateType = 'Payment';
            let _form = Ext.create('App.Control.Kivii.Finances.InvoiceApply.Execute.Form', {
                header: false
            });
            let _win = Ext.create('Ext.window.Window', {
                layout: 'fit',
                title: '申请开票',
                iconCls: 'x-fa fa-money',
                iconAlign: 'left',
                // header:false,
                autoScroll: true,
                width: 1000,
                height: 650,
                modal: true,
                resizable: false,
                items: [_form]
            });
            _win.show();
            _form.setOwner(_apply);
            _form.on('entityCreated', function(_ctrl, _entity) {
                _win.close();
                _view.reload();
            });
        },
        _onAcceptInvoice: function(_ctrl) {
            let _controller = this;
            let _view = _controller.getView();
            let _vm = _controller.getViewModel();
            let _selecteds = _vm.data.selections || [];
            if (!_view.selection) return;
            if (_selecteds.length <= 0) return;
            let _tip=false;
            for (let _i = 0; _i < _selecteds.length; _i++) {
                let _select = _selecteds[_i].data;
                if (_select.PayerName !== _selecteds[0].data.PayerName)_tip=true;
            }
            if(_tip){
	            let _msg = Ext.create('Ext.window.MessageBox', {
	                iconCls: _ctrl.iconCls,
	                iconAlign: 'left',
	                closeAction: 'destroy'
	            });
	            _msg.confirm(_ctrl.text, '所选到账中存在不同的付款单位,是否继续?', _ctrl.multiple?_controller._acceptMultiInvoice:_controller._acceptInvoice, _controller);
	            return;
            }
            if(!_ctrl.multiple)_controller._acceptInvoice('yes');
            else _controller._acceptMultiInvoice('yes');
        },
        _acceptInvoice: function(_optional) {
            if (_optional != "yes") return;
            let _controller = this;
            let _vm = _controller.getViewModel();
            let _view = _controller.getView();
            let _selecteds = _vm.data.selections || [];
            if (!_view.selection) return;
            if (_selecteds.length <= 0) return;
            let _item = _controller._initEntity(_selecteds);
            _item.OperateTime = null;
            let _form = Ext.create('App.Control.Kivii.Finances.Invoice.Form', {
                header: false
            });
            let _win = Ext.create('Ext.window.Window', {
                layout: 'fit',
                title: '录入发票',
                iconCls: 'x-fa fa-plus',
                iconAlign: 'left',
                // header:false,
                autoScroll: true,
                width: 1200,
                height: 750,
                modal: true,
                maximizable: true,
                resizable: true,
                items: [_form]
            });
            _win.show();
            _form.setOwner(_item);
            _form.on('entityAccepted', function(_ctrl, _entity) {
                _win.close();
                _view.reload();
            });
        },
        _acceptMultiInvoice: function(_optional) {
            if (_optional != "yes") return;
            let _controller = this;
            let _vm = _controller.getViewModel();
            let _view = _controller.getView();
            let _selecteds = _vm.data.selections || [];
            if (!_view.selection) return;
            if (_selecteds.length <= 0) return;
            let _item = _controller._initEntity(_selecteds);
            _item.OperateTime = null;
            let _form = Ext.create('App.Control.Kivii.Finances.Invoice.MultiAccept.List', {
                header: false
            });
            let _win = Ext.create('Ext.window.Window', {
                layout: 'fit',
                title: '批录入发票',
                iconCls: 'x-fa fa-ticket',
                iconAlign: 'left',
                // header:false,
                autoScroll: true,
                width: 800,
                height: 400,
                modal: true,
                maximizable: true,
                resizable: true,
                items: [_form]
            });
            _win.show();
            _form.setOwner(_item);
            _form.on('entityAccepted', function(_ctrl, _entity) {
                _win.close();
                _view.reload();
            });
        }
    }
});